@@ -115,7 +115,8 @@ from sphinx.ext.autodoc import (
 		DataDocumenter,
 		Documenter,
 		ModuleDocumenter,
-		ModuleLevelDocumenter
+		ModuleLevelDocumenter,
+		Options
 		)
 from sphinx.ext.autodoc.directive import DocumenterBridge
 from sphinx.util.inspect import object_description, safe_getattr
@@ -187,7 +188,7 @@ class VariableDocumenter(DataDocumenter):
 
 	directivetype = "data"
 	objtype = "variable"
-	priority = DataDocumenter.priority + 1
+	priority: float = DataDocumenter.priority + 0.5  # type: ignore  # keeps it below TypeVarDocumenter
 	option_spec = {
 			"no-value": flag,
 			"no-type": flag,
@@ -196,6 +197,10 @@ class VariableDocumenter(DataDocumenter):
 			**DataDocumenter.option_spec,
 			}
 
+	def __init__(self, directive: DocumenterBridge, name: str, indent: str = '') -> None:
+		super().__init__(directive=directive, name=name, indent=indent)
+		self.options = Options(self.options.copy())
+
 	def add_directive_header(self, sig: str):
 		"""
 		Add the directive's header.
@@ -257,6 +262,10 @@ class TypedAttributeDocumenter(AttributeDocumenter):
 		Now uses the type of the variable if it is not explicitly annotated.
 	"""  # noqa D400
 
+	def __init__(self, directive: DocumenterBridge, name: str, indent: str = '') -> None:
+		super().__init__(directive=directive, name=name, indent=indent)
+		self.options = Options(self.options.copy())
+
 	def add_directive_header(self, sig: str):
 		"""
 		Add the directive's header.
@@ -334,10 +343,10 @@ class InstanceAttributeDocumenter(TypedAttributeDocumenter):
 
 		This documenter only documents INSTANCEATTR members.
 
-		:param member:
-		:param membername:
+		:param member: The member being checked.
+		:param membername: The name of the member.
 		:param isattr:
-		:param parent:
+		:param parent: The parent of the member.
 		"""
 
 		return not isinstance(parent, ModuleDocumenter) and isattr and member is INSTANCEATTR
@@ -400,10 +409,10 @@ class SlotsAttributeDocumenter(TypedAttributeDocumenter):
 
 		This documenter only documents SLOTSATTR members.
 
-		:param member:
-		:param membername:
+		:param member: The member being checked.
+		:param membername: The name of the member.
 		:param isattr:
-		:param parent:
+		:param parent: The parent of the member.
 		"""
 
 		return member is SLOTSATTR
